@@ -4,102 +4,102 @@
 <context>
     <name>DownloadWidget</name>
     <message>
-        <location filename="../downloadwidget.ui" line="14"/>
+        <location filename="../src/downloadwidget.ui" line="14"/>
         <source>Download Manager</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="42"/>
+        <location filename="../src/downloadwidget.cpp" line="42"/>
         <source>Save as</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="50"/>
+        <location filename="../src/downloadwidget.cpp" line="50"/>
         <source>cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="89"/>
+        <location filename="../src/downloadwidget.cpp" line="89"/>
         <source>%L1 B</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="91"/>
+        <location filename="../src/downloadwidget.cpp" line="91"/>
         <source>%L1 KiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="93"/>
+        <location filename="../src/downloadwidget.cpp" line="93"/>
         <source>%L1 MiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="95"/>
+        <location filename="../src/downloadwidget.cpp" line="95"/>
         <source>%L1 GiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="102"/>
+        <location filename="../src/downloadwidget.cpp" line="102"/>
         <source>%1sec.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="104"/>
+        <location filename="../src/downloadwidget.cpp" line="104"/>
         <source>%1min. %2sec.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="106"/>
+        <location filename="../src/downloadwidget.cpp" line="106"/>
         <source>%1h. %2m. %3s.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="126"/>
+        <location filename="../src/downloadwidget.cpp" line="127"/>
         <source>%p% - %1 of %2 at %3/s - %4 left</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="128"/>
+        <location filename="../src/downloadwidget.cpp" line="129"/>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="133"/>
+        <location filename="../src/downloadwidget.cpp" line="134"/>
         <source>unknown size - %1 at %2/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="139"/>
+        <location filename="../src/downloadwidget.cpp" line="140"/>
         <source>completed - %1 at %2/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="144"/>
+        <location filename="../src/downloadwidget.cpp" line="145"/>
         <source>cancelled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="149"/>
+        <location filename="../src/downloadwidget.cpp" line="150"/>
         <source>interrupted: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="155"/>
+        <location filename="../src/downloadwidget.cpp" line="156"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="156"/>
+        <location filename="../src/downloadwidget.cpp" line="157"/>
         <source>Cancel downloading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="159"/>
+        <location filename="../src/downloadwidget.cpp" line="160"/>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="160"/>
+        <location filename="../src/downloadwidget.cpp" line="161"/>
         <source>Remove from list</source>
         <translation type="unfinished"></translation>
     </message>
@@ -107,218 +107,236 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="98"/>
+        <location filename="../src/mainwindow.cpp" line="107"/>
         <source>Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="114"/>
+        <location filename="../src/mainwindow.cpp" line="131"/>
+        <location filename="../src/mainwindow.cpp" line="840"/>
         <source>Move up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="124"/>
+        <location filename="../src/mainwindow.cpp" line="149"/>
+        <location filename="../src/mainwindow.cpp" line="841"/>
         <source>Move down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="133"/>
+        <location filename="../src/mainwindow.cpp" line="167"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="136"/>
+        <location filename="../src/mainwindow.cpp" line="170"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
+        <location filename="../src/mainwindow.cpp" line="172"/>
         <source>Rename bookmark:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="144"/>
-        <location filename="../mainwindow.cpp" line="159"/>
+        <location filename="../src/mainwindow.cpp" line="178"/>
+        <location filename="../src/mainwindow.cpp" line="193"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="177"/>
+        <location filename="../src/mainwindow.cpp" line="234"/>
         <source>&amp;Clear history</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="196"/>
+        <location filename="../src/mainwindow.cpp" line="277"/>
         <source>Home</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="197"/>
+        <location filename="../src/mainwindow.cpp" line="310"/>
         <source>Zoom In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="199"/>
+        <location filename="../src/mainwindow.cpp" line="308"/>
         <source>Zoom out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="214"/>
+        <location filename="../src/mainwindow.cpp" line="297"/>
         <source>search in page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="226"/>
+        <location filename="../src/mainwindow.cpp" line="290"/>
         <source>Add bookmark</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="234"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="739"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../src/mainwindow.cpp" line="341"/>
         <source>Select file to open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="260"/>
+        <location filename="../src/mainwindow.cpp" line="342"/>
         <source>Hypertext Files (*.htm *.html);;All Files (*.*)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="373"/>
+        <location filename="../src/mainwindow.cpp" line="437"/>
         <source>Keyboard Shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../src/mainwindow.cpp" line="438"/>
         <source>Ctrl-F, or F3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../src/mainwindow.cpp" line="438"/>
         <source>Find</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../src/mainwindow.cpp" line="438"/>
         <source>Shift-F3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="439"/>
         <source>Find previous</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="439"/>
         <source>Ctrl-R, or F5</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="439"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="376"/>
+        <location filename="../src/mainwindow.cpp" line="440"/>
         <source>Ctrl-O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="376"/>
+        <location filename="../src/mainwindow.cpp" line="440"/>
         <source>Browse file to open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="376"/>
+        <location filename="../src/mainwindow.cpp" line="440"/>
         <source>Esc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="377"/>
+        <location filename="../src/mainwindow.cpp" line="441"/>
         <source>Stop loading/clear Find field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="377"/>
+        <location filename="../src/mainwindow.cpp" line="441"/>
         <source>Alt→, Alt←</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="378"/>
+        <location filename="../src/mainwindow.cpp" line="442"/>
         <source>Back/Forward</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="378"/>
+        <location filename="../src/mainwindow.cpp" line="442"/>
         <source>F1, or ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="378"/>
+        <location filename="../src/mainwindow.cpp" line="442"/>
         <source>Open this help dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="528"/>
         <source>Press [F11] to exit full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="520"/>
+        <location filename="../src/mainwindow.cpp" line="625"/>
         <source>&amp;New tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
+        <location filename="../src/mainwindow.cpp" line="638"/>
         <source>&amp;Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="525"/>
+        <location filename="../src/mainwindow.cpp" line="640"/>
+        <source>&amp;Developer Tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="642"/>
         <source>H&amp;istory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="527"/>
+        <location filename="../src/mainwindow.cpp" line="644"/>
         <source>&amp;Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../src/mainwindow.cpp" line="646"/>
         <source>&amp;Bookmarks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="532"/>
+        <location filename="../src/mainwindow.cpp" line="649"/>
         <source>Bookmark current address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../src/mainwindow.cpp" line="651"/>
+        <source>Manage &amp;bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="673"/>
+        <source>&amp;Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="676"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="537"/>
+        <location filename="../src/mainwindow.cpp" line="677"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="539"/>
+        <location filename="../src/mainwindow.cpp" line="679"/>
         <source>&amp;Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="568"/>
+        <location filename="../src/mainwindow.cpp" line="684"/>
         <source>About MX Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="569"/>
+        <location filename="../src/mainwindow.cpp" line="685"/>
         <source>This is a VERY basic browser based on Qt WebEngine.
 
 The main purpose is to provide a basic document viewer for MX documentation. It could be used for LIMITED internet browsing, but it&apos;s not recommended to be used for anything important or secure because it&apos;s not a fully featured browser and its security/privacy features were not tested.
@@ -330,56 +348,116 @@ MX Viewer is distributed in the hope that it will be useful, but WITHOUT ANY WAR
 You should have received a copy of the GNU General Public License along with MX Viewer.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="91"/>
-        <source>This tool will display the URL content in a window, window title is optional</source>
+        <location filename="../src/mainwindow.cpp" line="721"/>
+        <source>Developer Tools</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="94"/>
-        <source>Start program in full-screen mode</source>
+        <location filename="../src/mainwindow.cpp" line="742"/>
+        <source>Open new tabs with home page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="95"/>
-        <source>Disable load images automatically from websites</source>
+        <location filename="../src/mainwindow.cpp" line="744"/>
+        <source>Show progress bar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../src/mainwindow.cpp" line="750"/>
+        <source>Enable spatial navigation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="752"/>
         <source>Disable JavaScript</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="100"/>
-        <source>Drop program&apos;s rights to &apos;nobody&apos;. By default, if run as root, the rights are dropped to normal user. This option might provide additional protection, but the program would not be able to write its cache and cookies to the user directory, so it might break some functionality.</source>
+        <location filename="../src/mainwindow.cpp" line="754"/>
+        <source>Load images</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="105"/>
-        <source>Enable spatial navigation with keyboard</source>
+        <location filename="../src/mainwindow.cpp" line="757"/>
+        <source>Home address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
-        <source>URL</source>
+        <location filename="../src/mainwindow.cpp" line="760"/>
+        <source>Zoom level</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="107"/>
-        <source>URL of the page you want to load</source>
+        <location filename="../src/mainwindow.cpp" line="824"/>
+        <source>Manage bookmarks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="109"/>
+        <location filename="../src/mainwindow.cpp" line="835"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="109"/>
+        <location filename="../src/mainwindow.cpp" line="836"/>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="842"/>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../src/main.cpp" line="112"/>
+        <source>This tool will display the URL content in a window, window title is optional</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="115"/>
+        <source>Start program in full-screen mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="116"/>
+        <source>Disable load images automatically from websites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="117"/>
+        <source>Disable JavaScript</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="121"/>
+        <source>Drop program&apos;s rights to &apos;nobody&apos;. By default, if run as root, the rights are dropped to normal user. This option might provide additional protection, but the program would not be able to write its cache and cookies to the user directory, so it might break some functionality.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="126"/>
+        <source>Enable spatial navigation with keyboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="127"/>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="128"/>
+        <source>URL of the page you want to load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="130"/>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="130"/>
         <source>Window title for the viewer</source>
         <translation type="unfinished"></translation>
     </message>
@@ -387,7 +465,7 @@ You should have received a copy of the GNU General Public License along with MX
 <context>
     <name>TabWidget</name>
     <message>
-        <location filename="../tabwidget.cpp" line="80"/>
+        <location filename="../src/tabwidget.cpp" line="80"/>
         <source>New Tab</source>
         <translation type="unfinished"></translation>
     </message>
